/* Copyright (C) 1999 Jeff Heflin - University of Maryland

   This software is provided under the terms of the GNU General Public
   License Version 2, June 1991. See the file License.html for details.
*/

package Expose;

import java.util.*;

/** A queue of items in which those with the lowest scores are inserted
  near the front of the list. */
public class SearchList extends Vector {

  public SearchList() {

    super();
  }

  public void addNode(int score, Object obj) {
    /* walks through the list, and places the new node after all other nodes
       with the same score, but before any nodes with a higher score. If
       it finds the same object with a lower score, then the new object is
       ignored. If the in-list object has a higher score, then it is removed.
       */
    boolean placed = false;
    SearchNode node;
    SearchNode newNode;
    int i = 0;

    newNode = new SearchNode(score, obj);
    while (i < elementCount) {
      node = (SearchNode)elementData[i];
      if (placed == false) {
	if (score < node.score) {           // found sort position
	  insertElementAt(newNode, i);
	  placed = true;
	}      
	else if (obj.equals(node.content))   // lower value for same node
	  placed = true;
      }
      else {                           // already found or placed in list
	if (obj.equals(node.content))
	  removeElement(node);
      }
      i++;
    }
    if (placed == false)
      addElement(newNode);
  }

  public Object getNextNode() {

    SearchNode node;
    Object obj;

    node = (SearchNode)firstElement();
    removeElement(node);
    obj = node.content;
    return obj;
  }

}

/** An item in a SearchList. */
class SearchNode {

  int score;
  Object content;

  public SearchNode(int score, Object content) {

    this.score = score;
    this.content = content;
  }

  public String toString() {

    return "(" + score + ", " + content + ")";
  }
}
