/* Copyright (C) 1999 Jeff Heflin - University of Maryland
 *	
 * This software is provided under the terms of the GNU Lesser General Public
 * License Version 2.1, February 1999. See the header in ShoeKb.java
 * and the file License.html for details.
 */

/* Change History:
      06/11/02 JDH - Removed unnecessary import statements
      12/29/00 JDH - Added a constructor for unary predicate atoms
*/

package ShoeKb;

/** A logical atom. An atom consists of a predicate and a set of
  arguments. The arguments may be variables or literals. If they
  are variables, then they are preceded by a question mark. */
public class Atom {

  String predicate;
  String[] arguments;

  /* Constructor for an atom with an arbitrary number of arguments. */
  public Atom(String predicate, String[] arguments) {

    this.predicate = predicate;
    this.arguments = arguments;
  }

  /** A shorthand constructor for an atom with a binary predicate. */
  public Atom(String predicate, String arg1, String arg2) {

    this.predicate = predicate;
    arguments = new String[2];
    arguments[0] = arg1;
    arguments[1] = arg2;
  }

  /** A shorthand constructor for an atom with a unary predicate. */
  public Atom(String predicate, String arg) {

    this.predicate = predicate;
    arguments = new String[1];
    arguments[0] = arg;
  }

  /** Return the name of the atom's predicate.*/
  public String getPredicate() {

    return predicate;
  }

  /** Return an array of the atom's arguments. */
  public String[] getArguments() {

    return arguments;
  }

  public String toString() {

    StringBuffer sbuf;
    int i;

    sbuf = new StringBuffer();
    sbuf.append("(" + predicate);
    for (i=0; i < arguments.length; i++)
      sbuf.append(" " + arguments[i]);
    sbuf.append(")");
    return sbuf.toString();
  }

}
