package ShoeMsAccess;

/**
 * <p>Title: SS_Frame</p>
 * <p>Description: Access version of ss_Frame</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Lehigh University</p>
 * @author Zhengxiang Pan
 * @version 1.0
 *

 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Authors: Zhengxiang Pan
 * Contact: Zhengxiang Pan (zhp2@lehigh.edu)
 *
 */

import SHOE.*;
import ShoeKb.*;
import Tree.*;
import UserInt.ApplType;
import UserInt.ArrayMenuBar;
import UserInt.BorderedPanel;
import UserInt.GridBagCreator;
import UserInt.LightComponentScroller;
import UserInt.MultiColumn;
import UserInt.Notification;
import UserInt.TreeWidget;
import java.applet.AppletContext;
import java.applet.Applet;
import java.awt.*;
import java.util.*;
import java.net.*;
import java.io.*;
import ShoeSearch.*;
/** This is the main class of the ShoeSearch application. It sets up the
  various panels and responds to user events.
*/
public class SS_Frame extends ShoeSearch.SS_Frame
{

  /* Default server settings  */
  /* These can be set to custom values by subclassing this class. */
  protected static String DEFAULT_HOST    = "dell";
  protected static int    DEFAULT_PORT    = 80;
  protected static String DEFAULT_KB_NAME = "shoe";

  protected static final String PROXY_FILE = "ontproxy.dat";

  public static void main (String[] args)
  {
    int    portnum = 0;

    SS_Frame app = null;

    ApplType.setApplication();

    if (args.length == 0) {

	System.err.println("Usage: java ShoeSearch.SS_Frame [kbname] ");

	System.exit(1);

    }
    else if (args.length == 1) {

      app = new SS_Frame(DEFAULT_HOST, DEFAULT_PORT, args[0], null);
    }
    else if (args.length == 3) {
      try {
	portnum = Integer.parseInt(args[2]);
      } catch (NumberFormatException ex) {
	System.err.println("Port number argument must be an integer.");
	System.exit(1);
      }
      app = new SS_Frame(args[1], portnum, args[0], null);
    }
    else {
      System.err.println("Usage: java ShoeSearch.SS_Frame [kbname] " +
			   "[host port]");
      System.exit(1);
    }
    if (app != null)
	app.show();
  }


  public SS_Frame (String kbHost, int kbPort, String kbName,
		   Applet srcApplet)
  {
      super(kbHost,kbPort,kbName,srcApplet);

  }



  /** Opens a SHOE Kb. */
  protected boolean connectToKb() {

    KBInterface baseKb;            // underlying KB for SHOE data
    PrintStream logOut;
    boolean     connected = false;

    baseKb = getKbInterface();
    logOut = System.out;
    kb = getAccessKb(baseKb, ontman, logOut);

    System.out.println("Connecting with parameters: " + kbHost + ", " +
		       kbPort + ", " + kbName);

    try {
      kb.openKB(kbName); //by zpan
      connected = true;
    } catch (KBException ex) {
      if (context != null) {
	/* we have not created the frame yet, so send messages to applet
	   context */
	context.showStatus(ex.getMessage());
	logOut.println(ex.getMessage());
	connected = false;
      }
      else {
	logOut.println(ex.getMessage());
	connected = false;
	// should we also beep? prevent queries if no KB was opened?
      }
    }
    return connected;
  }


  /** Returns a ShoeKb object which allows standard SHOE operations to be
    excuted against an underlying knowledge base. This function can be
    overriden so that a subclass of ShoeKb with an alternate implementation
    can be returned. */
  public AccessKb getAccessKb(KBInterface kb, OntManager ontman,
			  PrintStream logOut) {

    return new AccessKb(null, ontman, logOut, false);
  }

  /** Returns a KB interface suitable for querying. This
      function can be overriden so that different backends can be
      used. */
  public KBInterface getKbInterface() {

    //System.out.println("Using Parka for KB");
    //return new ParkaInterface();
    return null;
    //by zpan
  }




  /* ******** Private Methods ********* */


}



