/* Copyright (C) 1999 PLUS Group - University of Maryland
 *	
 * This software is provided under the terms of the GNU General Public
 * License Version 2, June 1991. See the header in SS_Frame.java
 * and the file License.html for details.
 */

package ShoeSearch;

import java.net.*;
import java.io.*;
import java.awt.*;

/** This class becomes part of the primary window used to communicate
   with the Parka server.  Sets up the sockets for communicating.
*/
public class  ThesServe  extends java.lang.Object
{
    Socket       socket;
    InputStream  instream;
    OutputStream outstream;

    private String   hostname;
    private int      port;

    ThesaurusClientParent tcParent;

    int            status;
    public String  connectionMsg;

    // Messages generated by object's actions:
    //
    static final int   CONN_OK = 0;
    static final int   CONN_UNKHOST = 1;
    static final int   CONN_BINDEXCPT = 2;
    static final int   CONN_CONNEXCPT = 3;
    static final int   CONN_SOCKFAIL = 4;
    static final int   CONN_IOERR = 5;
    static final int   CONN_ILLARGEXCPT = 6;
    static final int   CONN_DISCONIOERR = 7;
    static final int   CONN_REJECT = 8;

    static final String CONNUNKHOSTMSG = "Connect Failed: Unknown Host Error";
    static final String CONNCONNFAILMSG = "Connect Failed: ";
    static final String CONNSOCKFAILMSG = "Connect Failed: Socket Failure";
    static final String CONNIOERRMSG = "Connect Failed: IO Error";
    static final String CONNDISCONIOERRMSG = "IO Error during disconnect";
    static final String CONNWAIT = "Connection -- Waiting";

    static public final String  CONNATTEMPT = "Connecting to Thesaurus Server";
    static public final String  DISCONNATTEMPT = "Disconnecting from Thesaurus Server";
    static public final String  NOCONNMSG = "Not connected to server.";
    static public final String  CONNMSG = "Connected to server.";

    public ThesServe (ThesaurusClientParent parent)
    {
	socket = null;
        instream = null;
        outstream = null;
	connectionMsg = NOCONNMSG;
	status = CONN_REJECT;  //we begin with no connection
	tcParent = parent;

	//defaults:
	hostname = "scruffy.cs.umd.edu";
	port = 8989;

        connect();
    }

    protected void finalize()
    {
	if (isConnection())
	{
	    disconnect();
	}
    }

    // Returns true if there is a connection to the thesaurus server open
    public boolean isConnection()
    {
        return ((socket != null) && (instream != null)
                            && (outstream != null));
    }

    public int connect()
    {
	status = CONN_OK;
	connectionMsg = "";

//TEST
	System.out.println ("Start connection to thesaurus server");

        try
        {
            // close socket if one exists
            if (isConnection())
                disconnect();
//TEST
	System.out.println ("Create socket and I/O streams");

            // Create new socket and streams
            connectionMsg = CONNWAIT;
	    tcParent.displayTServeMsg (connectionMsg);
            socket = new Socket (hostname, port);
            instream = socket.getInputStream();
            outstream = socket.getOutputStream();
                // listening socket -- successful connect
            connectionMsg = CONNMSG;
	    tcParent.displayTServeMsg (connectionMsg);
        }
        catch (UnknownHostException uhe)
        {
	    status = CONN_UNKHOST;
	    connectionMsg = CONNUNKHOSTMSG;
	    tcParent.displayTServeMsg (connectionMsg);
        }
/* BindException and ConnectException are java 1.1...
        catch (BindException be)
        {
	    status = CONN_BINDEXCPT;
	    connectionMsg = CONNCONNFAILMSG + be.getMessage());
	    tcParent.displayTServeMsg (connectionMsg);
        }
        catch (ConnectException ce)
        {
	    status = CONN_CONNEXCPT;
	    connectionMsg = CONNCONNFAILMSG + ce.getMessage());
	    tcParent.displayTServeMsg (connectionMsg);
        }
*/
        catch (SocketException se)
        {
	    status = CONN_SOCKFAIL;
	    connectionMsg = CONNSOCKFAILMSG;
	    tcParent.displayTServeMsg (connectionMsg);
        }
        catch (IOException ioe)
        {
	    status = CONN_IOERR;
	    connectionMsg = CONNIOERRMSG;
	    tcParent.displayTServeMsg (connectionMsg);
        }
        catch (IllegalArgumentException  iae) //possible with illegal port#
        {
	    status = CONN_ILLARGEXCPT;
	    connectionMsg = CONNCONNFAILMSG + iae.getMessage();
	    tcParent.displayTServeMsg (connectionMsg);
        }

	return   status;
    }

    /* It is the caller's responsibility to make sure that any
       pre-requisites for disconnecting are met, such as files, or
       databases being closed first.
    */
    public int disconnect()
    {
        // disconnect from Parka if connected
        if (isConnection())
        {
            try
            {
                // Tell parka server we are exiting;
                // parka doesn't give a response
                ThesCommand c = new ThesCommand (outstream,
                                         ThesCommand.DISCONNECT, "");
                c.sendCommand();

                // Close streams
                instream.close();
                outstream.close();
                socket.close();

                instream = null;
                outstream = null;
                socket = null;

		status = CONN_REJECT;      //reinit to 'no connection'
		connectionMsg = NOCONNMSG;
	        tcParent.displayTServeMsg (connectionMsg);
            }
            catch (IOException e1)
            {
                // Close Error
		status = CONN_DISCONIOERR;
		connectionMsg = CONNDISCONIOERRMSG;
	        tcParent.displayTServeMsg (connectionMsg);
            }
        }

	return  status;
    }
}
